@@ -1,4 +1,4 @@
-// Heatbugs application. Copyright (C) 1996-1999 Santa Fe Institute.
+// Heatbugs application. Copyright  1996-1999 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -12,18 +12,18 @@
 // For a typical Swarm simulation, in main() you create a toplevel
 // Swarm, let it build and activate, and set it to running.
 
+
 int
 main (int argc, const char **argv)
 {
   id theTopLevelSwarm;
 
   // Swarm initialization: all Swarm apps must call this first.
-  initSwarmApp (argc, argv, "1.4.1", "bug-swarm@santafe.edu");
-
-  // swarmGUIMode is set in initSwarm(). It's set to be 0 if you
-  // typed heatbugs -batchmode. Otherwise, it's set to 1.
+  initSwarm (argc, argv);
   
-  if (swarmGUIMode == 1)
+  // swarmGUIMode is set in initSwarm(). It's set to be NO if you typed
+  // `heatbugs --batchmode' or `heatbugs -b'. Otherwise, it's set to YES.
+  if (swarmGUIMode == YES)
     {
       // We've got graphics, so make a full ObserverSwarm to get GUI objects
       theTopLevelSwarm = [HeatbugObserverSwarm createBegin: globalZone];
@@ -31,8 +31,12 @@ main (int argc, const char **argv)
       theTopLevelSwarm = [theTopLevelSwarm createEnd];
     }
   else
-    // No graphics - make a batchmode swarm and run it.
-    theTopLevelSwarm = [HeatbugBatchSwarm create: globalZone];
+    // No graphics - make a batchmode swarm (using the key
+    // `batchSwarm' from the default lispAppArchiver) and run it.
+    if ((theTopLevelSwarm = [lispAppArchiver getWithZone: globalZone 
+                                             object: "batchSwarm"]) == nil) 
+      raiseEvent(InvalidOperation, 
+                 "Can't find the parameters to create batchSwarm");
 
   [theTopLevelSwarm buildObjects];
   [theTopLevelSwarm buildActions];
