@@ -1,4 +1,4 @@
-// Market application. Copyright (C) 1996-1999 Santa Fe Institute.
+// Market application. Copyright  1996-1999 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -104,7 +104,7 @@ static unsigned numPredictorsToShow = 7;
   
   useHisto = [Histogram createBegin: globalZone];
   SET_WINDOW_GEOMETRY_RECORD_NAME (useHisto);
-  [useHisto setNumBins: numPredictorsToShow];
+  [useHisto setBinCount: numPredictorsToShow];
   useHisto = [useHisto createEnd];
 
   [useHisto enableDestroyNotification: self
