@@ -1,4 +1,4 @@
-// Market application. Copyright (C) 1996-1999 Santa Fe Institute.
+// Market application. Copyright  1996-1999 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -11,6 +11,7 @@
  * (Swarm) code taken and retooled to run under Swarm. Quick port, lots
  * of global variables left in.
  */
+#import <simtools.h>
 #import <simtoolsgui.h>
 #import "MarketObserverSwarm.h"
 
@@ -19,7 +20,7 @@ main (int argc, const char **argv)
 {
   MarketObserverSwarm *observerSwarm;
   
-  initSwarmApp (argc, argv, "1.4.1", "bug-swarm@santafe.edu");
+  initSwarm (argc, argv);
 
   observerSwarm = [MarketObserverSwarm createBegin: globalZone];
   SET_WINDOW_GEOMETRY_RECORD_NAME (observerSwarm);
