@@ -151,9 +151,8 @@
   
   triggerGraph = [EZGraph create: [self getZone] 
                           setTitle: "Trigger data vs. time"
-                          setAxisLabelsX: "time" Y: "number triggered"];
-
-  SET_WINDOW_GEOMETRY_RECORD_NAME (triggerGraph);
+                          setAxisLabelsX: "time" Y: "number triggered"
+                          setWindowGeometryRecordName: "triggerGraph"];
   
   // Now, we create two observations to plot on mousetraps with time:
   //    1) The total number of traps triggered so far
@@ -186,10 +185,8 @@
 
   // Next, create a 2d window to display the mousetrap world
   // and  set its size, zoom factor, title.
-
-  displayWindow = [ZoomRaster createBegin: self];
-  SET_WINDOW_GEOMETRY_RECORD_NAME (displayWindow);
-  displayWindow = [displayWindow createEnd];
+  displayWindow = [ZoomRaster create: self 
+                              setWindowGeometryRecordName: "displayWindow"];
   [displayWindow enableDestroyNotification: self
                  notificationMethod: @selector (_displayWindowDeath_:)];
   [displayWindow setColormap: colormap];
