@@ -5,10 +5,6 @@
 
 #import <objectbase/Swarm.h>
 #import <space.h>
-#import <activity.h>
-#import <collections.h>
-#import <objectbase.h>
-#import <simtools.h>
 
 @interface ModelSwarm: Swarm
 {
@@ -20,7 +16,7 @@
   int time;
 
   FoodSpace *foodSpace;
-  Grid2d *world;
+  id <Grid2d> world;
 
   id bugList;
   id modelActions;
